@@ -8,4 +8,5 @@ if VS.numActiveMissions()>1:
 else:
 	mission_lib.SetLastMission(0);
 	mission_lib.BriefLastMission(0,1)
-	VS.LoadMission('internal_mission_lib.mission')
+	mission_lib.LoadLastMission()
+	#VS.LoadMission('internal_mission_lib.mission')
