@@ -1,11 +1,45 @@
+import string
+
+# Independent of the date system used, this will scale how fast time progresses
+# in VS.
+#  1 will mean 1000 (real) seconds == 1 (VS) year
+#  2 will mean 500 (real) seconds == 1 (VS) year ... ie time is twice as fast
+SCALEFACTOR=1
+
+def formatStarDate(fac,stdt):
+    """Formats the stardate for news"""
+    stdtf=getFacCal(fac,stdt)
+    if fac == "confed":
+        return string.join([fillZeros(fac,stdtf[2]),str(stdtf[1]),str(stdtf[0]),formatTime(fac,stdt)])
+    else:
+        return string.join([fillZeros(fac,stdtf[2]),str(stdtf[1]),str(stdtf[0]),formatTime(fac,stdt)])
+
+def formatTime(fac,stdt):
+    """Formate the stardate time for news"""
+    stdtf=getFacCal(fac,stdt)
+    if fac == "confed":
+        return string.join([fillZeros(fac,stdtf[3]),fillZeros(fac,stdtf[4]),fillZeros(fac,stdtf[5])],":")
+    else:
+        return string.join([fillZeros(fac,stdtf[3]),fillZeros(fac,stdtf[4]),fillZeros(fac,stdtf[5])],":")
+
+def fillZeros(fac,tim):
+    """Returns a string with the required number of zeros for each faction"""
+    zer=2
+    tim=str(tim)
+    if fac == "confed":
+        zer=2
+    for i in range(zer):
+        if len(tim) < i+1:
+            tim='0'+tim
+    return tim
+
 def getFacCal(fac,stdt): #FIXME: add some other factions date systems....all ready to go :-)
     """takes a stardate string and returns a list of ints with
     [year,month,date,hour,minute,second]"""
     datesys = getDateSystem(fac)
-    facstdt = float(stdt)*datesys[3]
+    facstdt = (float(stdt)*SCALEFACTOR+float(getZeroStarDate(fac)))*datesys[3]
     incyear = int(facstdt)/1000
-    year = incyear+getZeroYear("faction")
-    return [year] + getMDDHMS(facstdt-(incyear*1000),datesys,year,fac)
+    return [incyear] + getMDDHMS(facstdt-(incyear*1000),datesys,incyear,fac)
 
 def daysinMonth(monthsystem,month):
     for mon in monthsystem:
@@ -38,8 +72,8 @@ def getMDDHMS(frac,system,year,fac):
             mon = monthsystem[i][0]
             break
         else:
-            remdays = numdays - countdays + 1    #FIXME: not sure exactly why the 1 is required, I think
-                                        #it is so that a fractional day would be counted as
+            remdays = numdays - countdays    #FIXME: not sure exactly why the 1 is required, I think
+                            #it is so that a fractional day would be counted as
                                         #the 1st, 3.5 days into the month the 4th day etc
     days = int(remdays)
     remainder = remdays - days
@@ -50,7 +84,7 @@ def getMDDHMS(frac,system,year,fac):
     minutes = int(mintemp)
     sectemp = (mintemp - minutes) * system[1][2]
     seconds = int(sectemp)
-    return [mon,days,hours,minutes,seconds]
+    return [mon,days+1,hours,minutes,seconds]
 
 
 def getDateSystem(faction):
@@ -65,11 +99,12 @@ def getStarToDay(monthsystem):
     """returns a particlar races stardate to day ratio"""
     return daysinYear(monthsystem) / 1000.0
 
-def getZeroYear(faction):
+def getZeroStarDate(faction):
+    """Returns the VS stardate at which each faction has the zero date."""
     if faction == "confed":
-        return 3141
+        return 3276800
     else:
-        return 3141
+        return 3276800
 
 def getLeap(year,faction):
     if faction == "confed":
